@@ -44,7 +44,7 @@ int main(int argc, char** argv)
     lowerPriority();
 
     KAboutData aboutData(QStringLiteral("baloo"), i18n("Baloo File Indexing Daemon"), PROJECT_VERSION);
-    aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), QStringLiteral("vhanda@kde.org"), QStringLiteral("http://vhanda.in"));
+    aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), QStringLiteral("vhanda@kde.org"), QStringLiteral("https://vhanda.in"));
 
     QCoreApplication app(argc, argv);
 
@@ -72,11 +72,9 @@ int main(int argc, char** argv)
         migrator.migrate();
     }
 
-    if (!QFile::exists(path + "/index")) {
-        indexerConfig.setInitialRun(true);
-    }
+    bool firstRun = !QFile::exists(path + "/index");
 
-    // HACK: Untill we start using lmdb with robust mutex support. We're just going to remove
+    // HACK: Until we start using lmdb with robust mutex support. We're just going to remove
     //       the lock manually in the baloo_file process.
     QFile::remove(path + "/index-lock");
 
@@ -90,7 +88,7 @@ int main(int argc, char** argv)
         qWarning() << "Failed to create database, removing corrupted database.";
         QFile::remove(path + "/index");
         QFile::remove(path + "/index-lock");
-        indexerConfig.setInitialRun(true);
+        firstRun = true;
 
         // try to create now after cleanup, if still no works => fail
         if (!db->open(Baloo::Database::CreateDatabase)) {
@@ -99,6 +97,6 @@ int main(int argc, char** argv)
         }
     }
 
-    Baloo::MainHub hub(db, &indexerConfig);
+    Baloo::MainHub hub(db, &indexerConfig, firstRun);
     return app.exec();
 }
